Module v17

Module v17 

A JSON-RPC client for testing against Bitcoin Core v0.17.

We ignore option arguments unless they effect the shape of the returned JSON data.

Modules

blockchain
Macros for implementing JSON-RPC methods on a client.
control
Macros for implementing JSON-RPC methods on a client.
generating
Macros for implementing JSON-RPC methods on a client.
mining
Macros for implementing JSON-RPC methods on a client.
network
Macros for implementing JSON-RPC methods on a client.
raw_transactions
Macros for implementing JSON-RPC methods on a client.
util
Macros for implementing JSON-RPC methods on a client.
wallet
Macros for implementing JSON-RPC methods on a client.
zmq
Macros for implementing JSON-RPC methods for the == Zmq == section (v0.17).

Structs

Client
Client implements a JSON-RPC client for the Bitcoin Core daemon or compatible APIs.
ImportMultiRequest
Args for the importmulti method.
Input
Input used as parameter to create_raw_transaction.
Output
Output used as parameter to create_raw_transaction.
TemplateRequest
Arg for the getblocktemplate method.
WalletCreateFundedPsbtInput
An element in the inputs argument of method walletcreatefundedpsbt.

Enums

AddNodeCommand
Args for the addnode method.
AddressType
Argument to the Client::get_new_address_with_type function.
ImportMultiScriptPubKey
scriptPubKey can be a string for script or json for address.
ImportMultiTimestamp
timestamp can be a number (UNIX epoch time) or the string "now".
SetBanCommand
Args for the setban method.
TemplateRules
Client side supported softfork deployment.