Client

Struct Client 

pub struct Client { /* private fields */ }
Client implements a JSON-RPC client for the Bitcoin Core daemon or compatible APIs.

Implementations

Source

impl Client

pub fn new(url: &str) -> Self

Creates a client to a bitcoind JSON-RPC server without authentication.

pub fn new_with_auth(url: &str, auth: Auth) -> Result<Self>

Creates a client to a bitcoind JSON-RPC server with authentication.

pub fn call<T: for<'a> Deserialize<'a>>( &self, method: &str, args: &[Value], ) -> Result<T>

Call an RPC method with given args list.

Source

impl Client

pub fn check_expected_server_version(&self) -> Result<()>

Checks that the JSON-RPC endpoint is for a bitcoind instance with the expected version.

Source

impl Client

pub fn best_block_hash(&self) -> Result<BlockHash>

Gets the blockhash of the current chain tip.

pub fn get_best_block_hash(&self) -> Result<GetBestBlockHash>

Source

impl Client

pub fn get_block(&self, hash: BlockHash) -> Result<Block>

Gets a block by blockhash.

pub fn get_block_verbose_zero( &self, hash: BlockHash, ) -> Result<GetBlockVerboseZero>

Gets a block by blockhash with verbose set to 0.

pub fn get_block_verbose_one( &self, hash: BlockHash, ) -> Result<GetBlockVerboseOne>

Gets a block by blockhash with verbose set to 1.

Source

impl Client

Source

impl Client

Source

impl Client

pub fn get_block_hash(&self, height: u64) -> Result<GetBlockHash>

Source

impl Client

Source

impl Client

pub fn get_block_stats_by_height( &self, height: u32, stats: Option<&[&str]>, ) -> Result<GetBlockStats>

pub fn get_block_stats_by_block_hash( &self, hash: &BlockHash, stats: Option<&[&str]>, ) -> Result<GetBlockStats>

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

pub fn get_tx_out(&self, txid: Txid, vout: u64) -> Result<GetTxOut>

Source

impl Client

pub fn get_tx_out_proof(&self, txids: &[Txid]) -> Result<String>

Source

impl Client

Source

impl Client

pub fn precious_block(&self, hash: BlockHash) -> Result<()>

Source

impl Client

pub fn prune_blockchain(&self, target: u64) -> Result<PruneBlockchain>

Instructs the node to prune the blockchain up to a specified height or timestamp.

Source

impl Client

pub fn save_mempool(&self) -> Result<()>

Source

impl Client

pub fn scan_tx_out_set_abort(&self) -> Result<ScanTxOutSetAbort>

Aborts an ongoing scantxoutset scan.

pub fn scan_tx_out_set_start( &self, scan_objects: &[&str], ) -> Result<ScanTxOutSetStart>

Starts a scan of the UTXO set for specified descriptors.

pub fn scan_tx_out_set_status(&self) -> Result<Option<ScanTxOutSetStatus>>

Checks the status of an ongoing scantxoutset scan.

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

pub fn help(&self) -> Result<String>

Source

impl Client

pub fn logging(&self) -> Result<Logging>

Source

impl Client

pub fn stop(&self) -> Result<String>

Source

impl Client

pub fn uptime(&self) -> Result<u32>

Source

impl Client

pub fn generate_to_address( &self, nblocks: usize, address: &Address, ) -> Result<GenerateToAddress>

Source

impl Client

pub fn generate(&self, nblocks: usize) -> Result<Generate>

Source

impl Client

pub fn invalidate_block(&self, hash: BlockHash) -> Result<()>

Source

impl Client

pub fn estimate_raw_fee(&self, conf_target: u32) -> Result<EstimateRawFee>

Panics
  • Panics if conf_target is outside the range [1, 1008].
Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

pub fn reconsider_block(&self, blockhash: BlockHash) -> Result<()>

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

pub fn prioritise_transaction( &self, txid: &Txid, fee_delta: SignedAmount, ) -> Result<bool>

Source

impl Client

pub fn submit_block(&self, block: &Block) -> Result<()>

Source

impl Client

pub fn add_node(&self, node: &str, command: AddNodeCommand) -> Result<()>

Source

impl Client

pub fn clear_banned(&self) -> Result<()>

Source

impl Client

pub fn disconnect_node(&self, address: &str) -> Result<()>

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

pub fn server_version(&self) -> Result<usize>

Returns the server version field of GetNetworkInfo.

pub fn get_network_info(&self) -> Result<GetNetworkInfo>

Source

impl Client

Source

impl Client

Source

impl Client

pub fn ping(&self) -> Result<()>

Source

impl Client

pub fn set_ban(&self, subnet: &str, command: SetBanCommand) -> Result<()>

Source

impl Client

Source

impl Client

pub fn combine_psbt(&self, txs: &[Psbt]) -> Result<CombinePsbt>

Source

impl Client

Source

impl Client

Source

impl Client

pub fn create_psbt( &self, inputs: &[Input], outputs: &[Output], ) -> Result<CreatePsbt>

Source

impl Client

pub fn create_raw_transaction( &self, inputs: &[Input], outputs: &[Output], ) -> Result<CreateRawTransaction>

Source

impl Client

pub fn decode_psbt(&self, psbt: &str) -> Result<DecodePsbt>

Source

impl Client

Source

impl Client

pub fn decode_script(&self, script: &str) -> Result<DecodeScript>

Source

impl Client

pub fn finalize_psbt(&self, psbt: &Psbt) -> Result<FinalizePsbt>

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

pub fn create_multisig( &self, nrequired: u32, keys: Vec<PublicKey>, ) -> Result<CreateMultisig>

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

pub fn verify_message( &self, address: &Address<NetworkChecked>, signature: &MessageSignature, message: &str, ) -> Result<VerifyMessage>

Source

impl Client

pub fn abandon_transaction(&self, txid: Txid) -> Result<()>

Source

impl Client

Source

impl Client

Source

impl Client

pub fn backup_wallet(&self, destination: &Path) -> Result<()>

Source

impl Client

pub fn bump_fee(&self, txid: Txid) -> Result<BumpFee>

Source

impl Client

pub fn create_wallet(&self, wallet: &str) -> Result<CreateWallet>

Source

impl Client

pub fn dump_priv_key(&self, address: &Address) -> Result<DumpPrivKey>

Source

impl Client

pub fn dump_wallet(&self, filename: &Path) -> Result<DumpWallet>

Source

impl Client

pub fn encrypt_wallet(&self, passphrase: &str) -> Result<EncryptWallet>

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

pub fn new_address(&self) -> Result<Address>

Gets a new address from bitcoind and parses it assuming its correct.

pub fn new_address_with_type(&self, ty: AddressType) -> Result<Address>

Gets a new address from bitcoind and parses it assuming its correct.

pub fn new_address_with_label( &self, label: &str, ) -> Result<Address<NetworkUnchecked>>

Gets a new address with label from bitcoind and parses it assuming its correct.

pub fn get_new_address( &self, label: Option<&str>, ty: Option<AddressType>, ) -> Result<GetNewAddress>

Gets a new address - low level RPC call.

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

pub fn import_address(&self, address: &Address) -> Result<()>

Source

impl Client

pub fn import_multi( &self, requests: &[ImportMultiRequest], ) -> Result<ImportMulti>

Source

impl Client

pub fn import_privkey(&self, privkey: &PrivateKey) -> Result<()>

Source

impl Client

pub fn import_pruned_funds( &self, raw_transaction: &str, tx_out_proof: &str, ) -> Result<()>

Source

impl Client

pub fn import_pubkey(&self, pubkey: &PublicKey) -> Result<()>

Source

impl Client

pub fn import_wallet(&self, filename: &Path) -> Result<()>

Source

impl Client

pub fn key_pool_refill(&self) -> Result<()>

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

Source

impl Client

pub fn load_wallet(&self, filename: &str) -> Result<LoadWallet>

Source

impl Client

pub fn lock_unspent(&self, outputs: &[(Txid, u32)]) -> Result<LockUnspent>

Lock the given list of transaction outputs. Returns true on success.

This wraps Core RPC: lockunspent false [{"txid":"..","vout":n},...].

pub fn unlock_unspent(&self, outputs: &[(Txid, u32)]) -> Result<LockUnspent>

Unlock the given list of transaction outputs. Returns true on success.

This wraps Core RPC: lockunspent true [{"txid":"..","vout":n},...].

Source

impl Client

pub fn remove_pruned_funds(&self, txid: Txid) -> Result<()>

Source

impl Client

Source

impl Client

pub fn send_many(&self, amounts: BTreeMap<Address, Amount>) -> Result<SendMany>

Source

impl Client

pub fn send_to_address( &self, address: &Address<NetworkChecked>, amount: Amount, ) -> Result<SendToAddress>

pub fn send_to_address_rbf( &self, address: &Address<NetworkChecked>, amount: Amount, ) -> Result<SendToAddress>

Source

impl Client

pub fn set_hd_seed(&self) -> Result<()>

Source

impl Client

pub fn set_tx_fee(&self, fee_rate: FeeRate) -> Result<SetTxFee>

Source

impl Client

pub fn sign_message( &self, address: &Address, message: &str, ) -> Result<SignMessage>

Source

impl Client

Source

impl Client

pub fn unload_wallet(&self, wallet_name: &str) -> Result<()>

Source

impl Client

Source

impl Client

pub fn wallet_lock(&self) -> Result<()>

Source

impl Client

pub fn wallet_passphrase(&self, passphrase: &str, timeout: u64) -> Result<()>

Source

impl Client

pub fn wallet_passphrase_change( &self, old_passphrase: &str, new_passphrase: &str, ) -> Result<()>

Source

impl Client

Source

impl Client