A JSON-RPC client for testing against Bitcoin Core v22.
We ignore option arguments unless they effect the shape of the returned JSON data.
Re-exports
pub use crate::client_sync::v17::AddNodeCommand;pub use crate::client_sync::v17::AddressType;pub use crate::client_sync::v17::ImportMultiRequest;pub use crate::client_sync::v17::ImportMultiScriptPubKey;pub use crate::client_sync::v17::ImportMultiTimestamp;pub use crate::client_sync::v17::Input;pub use crate::client_sync::v17::Output;pub use crate::client_sync::v17::SetBanCommand;pub use crate::client_sync::v17::TemplateRequest;pub use crate::client_sync::v17::TemplateRules;pub use crate::client_sync::v17::WalletCreateFundedPsbtInput;pub use crate::client_sync::v21::ImportDescriptorsRequest;
Structs
- Client
- Client implements a JSON-RPC client for the Bitcoin Core daemon or compatible APIs.