A JSON-RPC client for testing against Bitcoin Core v29.
We ignore option arguments unless they effect the shape of the returned JSON data.
Re-exports
pub use crate::client_sync::v17::Input;pub use crate::client_sync::v17::Output;pub use crate::client_sync::v17::WalletCreateFundedPsbtInput;pub use crate::client_sync::v23::AddressType;
Modules
- blockchain
- Macros for implementing JSON-RPC methods on a client.
Structs
- Client
- Client implements a JSON-RPC client for the Bitcoin Core daemon or compatible APIs.
- Template
Request - Arg for the
getblocktemplatemethod. (v29+).
Enums
- Template
Rules - Client side supported softfork deployment.