Module v30

Module v30 

A JSON-RPC client for testing against Bitcoin Core v30.

We ignore option arguments unless they effect the shape of the returned JSON data.

Re-exports

pub use crate::client_sync::v17::AddNodeCommand;
pub use crate::client_sync::v17::ImportMultiRequest;
pub use crate::client_sync::v17::ImportMultiScriptPubKey;
pub use crate::client_sync::v17::ImportMultiTimestamp;
pub use crate::client_sync::v17::Input;
pub use crate::client_sync::v17::Output;
pub use crate::client_sync::v17::SetBanCommand;
pub use crate::client_sync::v17::WalletCreateFundedPsbtInput;
pub use crate::client_sync::v17::FeeEstimateMode;
pub use crate::client_sync::v21::ImportDescriptorsRequest;
pub use crate::client_sync::v23::AddressType;
pub use crate::client_sync::v29::TemplateRequest;
pub use crate::client_sync::v29::TemplateRules;

Modules

blockchain
Macros for implementing JSON-RPC methods on a client.

Structs

Client
Client implements a JSON-RPC client for the Bitcoin Core daemon or compatible APIs.