A JSON-RPC client for testing against Bitcoin Core v0.17.
We ignore option arguments unless they effect the shape of the returned JSON data.
Modules
- blockchain
- Macros for implementing JSON-RPC methods on a client.
- control
- Macros for implementing JSON-RPC methods on a client.
- generating
- Macros for implementing JSON-RPC methods on a client.
- mining
- Macros for implementing JSON-RPC methods on a client.
- network
- Macros for implementing JSON-RPC methods on a client.
- raw_
transactions - Macros for implementing JSON-RPC methods on a client.
- util
- Macros for implementing JSON-RPC methods on a client.
- wallet
- Macros for implementing JSON-RPC methods on a client.
- zmq
- Macros for implementing JSON-RPC methods for the
== Zmq ==section (v0.17).
Structs
- Client
- Client implements a JSON-RPC client for the Bitcoin Core daemon or compatible APIs.
- Import
Multi Request - Args for the
importmultimethod. - Input
- Input used as parameter to
create_raw_transaction. - Output
- Output used as parameter to
create_raw_transaction. - Template
Request - Arg for the
getblocktemplatemethod. - Wallet
Create Funded Psbt Input - An element in the
inputsargument of methodwalletcreatefundedpsbt.
Enums
- AddNode
Command - Args for the
addnodemethod. - Address
Type - Argument to the
Client::get_new_address_with_typefunction. - Import
Multi Script PubKey scriptPubKeycan be a string for script or json for address.- Import
Multi Timestamp timestampcan be a number (UNIX epoch time) or the string"now".- SetBan
Command - Args for the
setbanmethod. - Template
Rules - Client side supported softfork deployment.